@@ -2,16 +2,16 @@ package App::GHPT::WorkSubmitter::ChangedFilesFactory;
 
 use App::GHPT::Wrapper::OurMoose;
 
-our $VERSION = '2.000000';
+our $VERSION = '2.000001';
 
-use IPC::Run3        qw( run3 );
-use App::GHPT::Types qw( ArrayRef HashRef Str );
-use App::GHPT::WorkSubmitter::ChangedFiles;
+use IPC::Run3                              qw( run3 );
+use App::GHPT::Types                       qw( ArrayRef HashRef Str );
+use App::GHPT::WorkSubmitter::ChangedFiles ();
 
 has changed_files_class => (
     is      => 'ro',
     isa     => Str,
-    default => 'App::GHPT::WorkSubmitter::ChangedFiles',
+    default => App::GHPT::WorkSubmitter::ChangedFiles::,
 );
 
 has merge_to_branch_name => (
@@ -170,7 +170,7 @@ App::GHPT::WorkSubmitter::ChangedFilesFactory - Work out what files have changed
 
 =head1 VERSION
 
-version 2.000000
+version 2.000001
 
 =head1 SYNOPSIS
 
