@@ -8,8 +8,6 @@ use App::GHPT::Wrapper::Ourperl;
 
 use Import::Into;
 use Test::Class::Moose 0.82 ();
-use Test::Class::Moose::AttributeRegistry ();
-use Test::More;
 use namespace::autoclean ();
 
 sub import {
